/**************************************************************************************************
* Project name: 
*     IR Reflect Click
* Company: 
*     (c) mikroElektronika, 2015
* Revision History:
*     15.06.2015. Initial release (DB & PT)
* Description:
*     IR reflect click carries a GP2S700HCP reflective photointerrupter. 
*     On this type of photointerrupter the infrared emitter and receiver are facing the same direction,
*     the infrared beam from the emitter gets bounced back to the receiver when an object is placed within the detecting range of
*     the sensor (optimal range is 3mm). IR reflect click communicates with the target board microcontroller through mikroBUS
*     AN and INT pins (an onboard potentiometer sets the Interrupt threshold). Its designed to use a 3.3V power supply only.
*     These sensors are used to detect an objects presence or motion, such as a piece of paper passing through a printer.
*     To avoid setting off false alarms, avoid exposing the sensor to other sources of infrared light
*     (which could come from an ordinary incandescent light bulb).
*     Also, black objects wont reflect infrared so the click wont detect them.
*     On the other hand, reflective metalic surfaces will trigger the sensor from a larger range.
*
* Test configuration:
*     MCU:             STM32F107VC
*                      http://www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/DATASHEET/CD00220364.pdf
*     Dev.Board:       EasyMx PRO v7 for STM32(R) ARM(R)
*                      http://www.mikroe.com/easymx-pro/stm32/
*     Oscillator:      HSE-PLL, 72.000MHz
*     Hardware:        IR Reflect Click
*                      http://www.mikroe.com/click/ir-reflect/
*     SW:              mikroC PRO for ARM
*                      http://www.mikroe.com/mikroc/arm/
* NOTES:
*     - Insert IR Reflect Click in mikroBUS socket 1
*     - Turn ON USB UARTA switches (SW12.1 and SW12.2).
*     - For UART communication use USB UART A port at 56000bps
**************************************************************************************************/

#include "resources.h"

// TFT module connections
unsigned int TFT_DataPort at GPIOE_ODR;
sbit TFT_RST at GPIOE_ODR.B8;
sbit TFT_RS at GPIOE_ODR.B12;
sbit TFT_CS at GPIOE_ODR.B15;
sbit TFT_RD at GPIOE_ODR.B10;
sbit TFT_WR at GPIOE_ODR.B11;
sbit TFT_BLED at GPIOE_ODR.B9;
// End TFT module connections

//sbit IR Reflect Interrupt at GPIOD_ODR.B10;
sbit IRRef_In at GPIOD_IDR.B10;


void InitDisplay(){
  TFT_Init_ILI9341_8bit(320, 240);
  TFT_BLED = 1;
  TFT_Set_Pen(CL_WHITE, 1);
  TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
  TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);

  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_Black, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_LIne(20,  46, 300,  46);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("IR Reflect Click", 90, 14);
  TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyMx PRO v7 for STM32", 19, 223);
  TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("www.mikroe.com", 200, 223);
  TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
}


void main(){
unsigned int adc_result;
char txt[6];

       InitDisplay();

       GPIO_Analog_Input(&GPIOA_IDR, _GPIO_PINMASK_4);        // Set GPIOA pin 4 as analog input
       GPIO_Digital_Input(&GPIOD_BASE, _GPIO_PINMASK_10);     // Set GPIOD pin 10 as digital input

       UART1_Init(56000);                                     // Initialize UART module at 56000 bps
       Delay_ms(100);                                         // Wait for UART module to stabilize

       UART1_Write_Text("Start");                             // Send Start to UART port
       UART1_Write(13);
       UART1_Write(10);
        
       ADC_Set_Input_Channel(_ADC_CHANNEL_4);                 // Set input ADC channel 4
       ADC1_Init();                                           // ADC module initialization

       while(1){
                 if (GPIOD_IDR.B10)
                        { 
                        // If IR Reflection is detected!!!
                        TFT_Set_Pen(CL_WHITE, 1);
                        TFT_Set_Brush(1, CL_WHITE, 0, LEFT_TO_RIGHT, CL_WHITE, CL_WHITE);
                        TFT_Rectangle(70,60,240,90);
                        TFT_Image_Jpeg(103, 100, interrupt_jpg);   // Show Interrupt jpg picture on display
                        TFT_Set_Font(&TFT_defaultFont, CL_RED, FO_HORIZONTAL);
                        TFT_Write_Text("Interrupt Detected!",90,65);
                        }
                     else
                        {
                        // If there is no IR Reflection
                        TFT_Set_Pen(CL_WHITE, 1);
                        TFT_Set_Brush(1, CL_WHITE, 0, LEFT_TO_RIGHT, CL_WHITE, CL_WHITE);
                        TFT_Rectangle(70,60,240,210);         // Clear text and picture
                        TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
                        TFT_Write_Text("No Interrupt",130,65);
                        }
                 adc_result = ADC1_Get_Sample(4);             // Get ADC value from PC3 pin
                 WordToStr(adc_result, txt);                  // Conversion to string
                 UART1_Write_Text(txt);                       // Sending ADC data to UART
                 UART1_Write(13);
                 UART1_Write(10);
                 Delay_ms(350);                               // Small delay
                 }

}